Examples
========

Below are some examples on how to use the Seagull. They are all in the form of
Jupyter notebooks. If you wish to contribute some cool ecosystems to display in
our gallery, then `please open a Pull Request <https://pyseagull.readthedocs.io/en/latest/contributing.html>`_!

You can also find the notebooks in this `link <https://github.com/ljvmiranda921/seagull/tree/master/docs/notebooks>`_.

.. image:: https://mybinder.org/badge_logo.svg
 :target: https://mybinder.org/v2/gh/ljvmiranda921/seagull/master?filepath=docs%2Fnotebooks


.. toctree::
   :maxdepth: 2

   notebooks/basic-usage
   notebooks/sprator

